@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: aeson-better-errors
 version: 0.9.0.1
-id: aeson-better-errors-0.9.0.1-59403b30f4f27006e990088f17fb37ed
-key: aeson_EbOfuT7YUGdAy9H9mOBktu
+id: aeson-better-errors-0.9.0.1-05a0fea2071afcbbba2c9016d32723d2
+key: aeson_80TtZrtZ1JfHcf9Z5lR5HD
 license: MIT
 maintainer: harry@garrood.me
 homepage: https://github.com/hdgarrood/aeson-better-errors
@@ -22,9 +22,9 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-better-errors-0.9.0.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-better-errors-0.9.0.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/aeson-better-errors-0.9.0.1
-hs-libraries: HSaeson-better-errors-0.9.0.1-EbOfuT7YUGdAy9H9mOBktu
+hs-libraries: HSaeson-better-errors-0.9.0.1-80TtZrtZ1JfHcf9Z5lR5HD
 depends:
-    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
+    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     dlist-0.7.1.2-60b8202d1ee1445c0a53e803464ea95b
@@ -35,7 +35,7 @@ depends:
     transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
-    void-0.7.1-5298c6b3a32576797627b9b87532f9cb
+    void-0.7.1-255c5771d2d826ed3cb8a752061ff594
 haddock-interfaces: /usr/share/doc/haskell-aeson-better-errors/html/aeson-better-errors.haddock
 haddock-html: /usr/share/doc/haskell-aeson-better-errors/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
